@@ -16,11 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from ..exceptions import PySideImportError
-try:
-    from PySide import QtCore
-except ImportError:
-    raise PySideImportError
+from ..Qt import QtCore
 
 
 class PluginListModel(QtCore.QAbstractListModel):
@@ -28,7 +24,7 @@ class PluginListModel(QtCore.QAbstractListModel):
 
     def __init__(self, plugins, parent=None):
         super(PluginListModel, self).__init__()
-        self.plugins = plugins
+        self.plugins = sorted(plugins)
 
     def rowCount(self, parent):
         return len(self.plugins)
@@ -47,7 +43,7 @@ class PluginListModel(QtCore.QAbstractListModel):
                 return QtCore.Qt.Unchecked
 
     def flags(self, index):
-        """Overwrites default flags to allow checking of items."""
+        """Overwrite default flags to allow checking of items."""
         return QtCore.Qt.ItemIsEnabled | QtCore.Qt.ItemIsUserCheckable
 
     def setData(self, index, value, role):
