@@ -16,12 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import os
-import pytest
+import unittest
 from pyparadox.Dlc import Dlc
 
 
-def test_dlc_name():
-    dlc = Dlc(os.path.join(os.path.dirname(__file__), "dlc",
-                           "dlc001.dlc"))
-    assert dlc.name == "Dynasty Coat of Arms Pack 1"
+class TestDlc(unittest.TestCase):
+
+    def test___init__(self):
+        dlc = Dlc("filename", "name")
+        self.assertEqual(dlc.filename, "filename")
+        self.assertEqual(dlc.name, "name")
+
+        dlc = Dlc("filename", "name", enabled=False)
+        self.assertFalse(dlc.enabled)
