@@ -16,12 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import os
-import pytest
+import unittest
 from pyparadox.Mod import Mod
 
 
-def test_mod_name():
-    mod = Mod(os.path.join(os.path.dirname(__file__), "mod",
-                           "better gender law mod.mod"))
-    assert mod.name == "Better gender law mod"
+class TestMod(unittest.TestCase):
+
+    def test___init__(self):
+        mod = Mod("filename", "name")
+        self.assertEqual(mod.filename, "filename")
+        self.assertEqual(mod.name, "name")
+
+        mod = Mod("filename", "name", enabled=False)
+        self.assertFalse(mod.enabled)
